/*  Autopackage GTK+ frontend
 *  Copyright (C) 2003  Hongli Lai <h.lai@chello.nl>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdlib.h>
#include <gtk/gtk.h>
#include "utils.h"
#include "main.h"


void
show_error (GtkWidget *parent, gchar *format, ...)
{
	GtkWidget *dialog;
	va_list ap;
	gchar *msg;

	va_start (ap, format);
	msg = g_strdup_vprintf (format, ap);
	va_end (ap);

	dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
		GTK_DIALOG_MODAL,
		GTK_MESSAGE_ERROR,
		GTK_BUTTONS_OK,
		msg);
	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
	gtk_dialog_run (GTK_DIALOG (dialog));
	gtk_widget_destroy (dialog);
	g_free (msg);
}


GladeXML *
load_glade (gchar *filename)
{
	GladeXML *xml;
	gchar *fn;
	gchar *gladedir = g_strdup_printf ("%s/glade", data_dir);
	const gchar *dirs[] = {
		#ifdef DEBUG
		g_strdup_printf ("%s/glade", g_getenv ("APKG_GTK_WORKING")),
		#endif
		gladedir,
		};
	gboolean found = FALSE;
	gint i;

	for (i = 0; i < sizeof (dirs) / sizeof (const gchar *); i++)
	{
		fn = g_strdup_printf ("%s/%s", dirs[i], filename);
		if (g_file_test (fn, G_FILE_TEST_EXISTS))
		{
			found = TRUE;
			break;
		}
		g_free (fn);
	}

	if (!found)
		goto err;

	xml = glade_xml_new (fn, NULL, DOMAIN);
	if (!xml) goto err;
	glade_xml_signal_autoconnect (xml);
	g_free (gladedir);
	g_free (fn);
	return xml;


	err:
	show_error (NULL,
		_("Unable to initialize the user interface file \"%s\". This frontend program must be terminated.\n\n"
		"Possible causes of this error:\n"
		"- This frontend program is improperly installed.\n"
		"- The installation is somehow damaged after it is installed.\n\n"
		"Please try reinstalling this program (autopackage-gtk).\n"
		"If that doesn't help, submit a bugreport to the Autopackage authors:\n"
		"http://autopackage.org/"),
		filename);
	exit (1);
}


gchar *
lookup_file (gchar *basename)
{
	gchar *fn;
	gchar *gladedir = g_strdup_printf ("%s/glade", data_dir);
	const gchar *dirs[] = {
		#ifdef DEBUG
		g_strdup_printf ("%s/glade", g_getenv ("APKG_GTK_WORKING")),
		#endif
		gladedir,
		};
	gboolean found = FALSE;
	gint i;

	for (i = 0; i < sizeof (dirs) / sizeof (const gchar *); i++)
	{
		fn = g_strdup_printf ("%s/%s", dirs[i], basename);
		if (g_file_test (fn, G_FILE_TEST_EXISTS))
		{
			found = TRUE;
			break;
		}
		g_free (fn);
	}

	if (!found)
		goto err;

	g_free (gladedir);
	return fn;


	err:
	show_error (NULL,
		_("Unable to load data file \"%s\". This frontend program must be terminated.\n\n"
		"Possible causes of this error:\n"
		"- This frontend program is improperly installed.\n"
		"- The installation is somehow damaged after it is installed.\n\n"
		"Please try reinstalling this program (autopackage-gtk).\n"
		"If that doesn't help, submit a bugreport to the Autopackage authors:\n"
		"http://autopackage.org/"),
		basename);
	exit (1);
}


GList *
create_strlist (gchar *str)
{
	GList *lines = NULL;

	do
	{
		gchar *end, *line;

		end = strchr (str, '\n');
		if (end)
		{
			line = g_strndup (str, end - str);
			stripNewline (line);
			lines = g_list_append (lines, line);
			str = end + 1;
		} else
		{
			lines = g_list_append (lines, g_strdup (str));
			break;
		}
	} while (1);

	if (strlen (((gchar *) g_list_last (lines)->data)) == 0)
		lines = g_list_remove_link (lines, g_list_last (lines));

	return lines;
}


void
free_strlist (GList *list)
{
	GList *tmp;

	if (!list) return;
	for (tmp = list; tmp; tmp = tmp->next)
		if (tmp->data) g_free (tmp->data);
	g_list_free (list);
}

